Module: Jazari::RunPolicy
- Defined in:
- lib/jazari/recipe.rb
Overview
Whether a ritual may run more than once in a day is a property of the RITUAL, not a global rule: verifying a backup should happen once a day; triaging an incident may happen five times.
Constant Summary collapse
- UNRESTRICTED =
"unrestricted"- ONCE_PER_CALENDAR_DAY =
"once_per_calendar_day"- ALL =
[ UNRESTRICTED, ONCE_PER_CALENDAR_DAY ].freeze